@@ -143,6 +143,8 @@ class LXDDriverTest(test.NoDBTestCase):
             raise lxdcore_exceptions.LXDAPIException(MockResponse(404))
         self.client.containers.get.side_effect = container_get
         configdrive.return_value = False
+        container = mock.Mock()
+        self.client.containers.create.return_value = container
 
         ctx = context.get_admin_context()
         instance = fake_instance.fake_instance_obj(ctx, name='test')
@@ -183,6 +185,7 @@ class LXDDriverTest(test.NoDBTestCase):
             instance, network_info)
         lxd_driver._add_ephemeral.assert_called_once_with(
             block_device_info, lxd_driver.client.host_info, instance)
+        container.start.assert_called_once_with(wait=True)
 
     def test_spawn_already_exists(self):
         """InstanceExists is raised if the container already exists."""
@@ -1267,3 +1270,29 @@ class LXDDriverTest(test.NoDBTestCase):
                 'disk_format': 'raw',
                 'container_format': 'bare'},
             data)
+
+    def test_container_isolated(self):
+        self.client.host_info = {'api_extensions': ['id_map']}
+        ctx = context.get_admin_context()
+        instance = fake_instance.fake_instance_obj(ctx, name='test')
+        instance.flavor.extra_specs = {'lxd:isolated': True}
+
+        lxd_driver = driver.LXDDriver(None)
+        lxd_driver.init_host(None)
+
+        config = lxd_driver.config_instance_options({}, instance)
+        self.assertEqual({'security.idmap.isolated': 'True',
+                          'boot.autostart': 'True'}, config)
+
+    def test_container_isolated_unsupported(self):
+        self.client.host_info = {'api_extensions': []}
+        ctx = context.get_admin_context()
+        instance = fake_instance.fake_instance_obj(ctx, name='test')
+        instance.flavor.extra_specs = {'lxd:isolated': True}
+
+        lxd_driver = driver.LXDDriver(None)
+        lxd_driver.init_host(None)
+
+        self.assertRaises(
+            exception.NovaException,
+            lxd_driver.config_instance_options, {}, instance)
