@@ -333,7 +333,7 @@ class LXDDriver(driver.ComputeDriver):
             profile.save()
 
         try:
-            container.start()
+            container.start(wait=True)
         except lxd_exceptions.LXDAPIException as e:
             with excutils.save_and_reraise_exception():
                 self.cleanup(
@@ -1432,6 +1432,16 @@ class LXDDriver(driver.ComputeDriver):
         if lxd_privileged_allowed:
             config['security.privileged'] = 'True'
 
+        lxd_isolated = flavor.extra_specs.get(
+            'lxd:isolated', False)
+        if lxd_isolated:
+            extensions = self.client.host_info.get('api_extensions', [])
+            if 'id_map' in extensions:
+                config['security.idmap.isolated'] = 'True'
+            else:
+                msg = _('Host does not support isolated instances')
+                raise exception.NovaException(msg)
+
         return config
 
     def configure_container_root(self, instance):
